@@ -2,22 +2,21 @@ source 'https://rubygems.org'
 
 gemspec path: '../'
 
-gem 'activerecord', '~> 4.2.1'
-gem 'railties', '~> 4.2.1'
-gem 'i18n', '~> 0.7.0'
+gem 'activerecord', '~> 5.2.0'
+gem 'railties', '~> 5.2.0'
 
 # Database Configuration
 group :development, :test do
   platforms :jruby do
-    gem 'activerecord-jdbcmysql-adapter', '~> 1.3.14'
-    gem 'activerecord-jdbcpostgresql-adapter', '~> 1.3.14'
+    gem 'activerecord-jdbcmysql-adapter', '~> 51.1'
+    gem 'activerecord-jdbcpostgresql-adapter', '~> 51.1'
     gem 'kramdown'
   end
 
   platforms :ruby, :rbx do
     gem 'sqlite3'
-    gem 'mysql2', '~> 0.4.10'
-    gem 'pg', '~> 0.15'
+    gem 'mysql2'
+    gem 'pg'
     gem 'redcarpet'
   end
 
